pub struct Orchard {
actions: Vec<OrchardAction>,
value_balance: f64,
value_balance_zat: i64,
flags: Option<OrchardFlags>,
anchor: Option<[u8; 32]>,
proof: Option<Vec<u8>>,
binding_sig: Option<[u8; 64]>,
}Expand description
Object with Orchard-specific information.
Fields
actions: Vec<OrchardAction>Array of Orchard actions.
value_balance: f64The net value of Orchard Actions in ZEC.
value_balance_zat: i64The net value of Orchard Actions in zatoshis.
flags: Option<OrchardFlags>The flags.
anchor: Option<[u8; 32]>A root of the Orchard note commitment tree at some block height in the past
proof: Option<Vec<u8>>Encoding of aggregated zk-SNARK proofs for Orchard Actions
binding_sig: Option<[u8; 64]>An Orchard binding signature on the SIGHASH transaction hash
Implementations
Sourceimpl Orchard
Auto-generated by derive_getters::Getters.
impl Orchard
Auto-generated by derive_getters::Getters.
Sourcepub fn actions(&self) -> &Vec<OrchardAction>
pub fn actions(&self) -> &Vec<OrchardAction>
Array of Orchard actions.
Sourcepub fn value_balance(&self) -> f64
pub fn value_balance(&self) -> f64
The net value of Orchard Actions in ZEC.
Sourcepub fn value_balance_zat(&self) -> i64
pub fn value_balance_zat(&self) -> i64
The net value of Orchard Actions in zatoshis.
Sourcepub fn flags(&self) -> &Option<OrchardFlags>
pub fn flags(&self) -> &Option<OrchardFlags>
The flags.
Sourcepub fn anchor(&self) -> Option<[u8; 32]>
pub fn anchor(&self) -> Option<[u8; 32]>
A root of the Orchard note commitment tree at some block height in the past
Sourcepub fn proof(&self) -> &Option<Vec<u8>>
pub fn proof(&self) -> &Option<Vec<u8>>
Encoding of aggregated zk-SNARK proofs for Orchard Actions
Sourcepub fn binding_sig(&self) -> Option<[u8; 64]>
pub fn binding_sig(&self) -> Option<[u8; 64]>
An Orchard binding signature on the SIGHASH transaction hash