pub struct ShieldedOutput {
cv: ValueCommitment,
cm_u: [u8; 32],
ephemeral_key: [u8; 32],
enc_ciphertext: [u8; 580],
out_ciphertext: [u8; 80],
proof: [u8; 192],
}Expand description
A Sapling output of a transaction.
Fields
cv: ValueCommitmentValue commitment to the input note.
cm_u: [u8; 32]The u-coordinate of the note commitment for the output note.
ephemeral_key: [u8; 32]A Jubjub public key.
enc_ciphertext: [u8; 580]The output note encrypted to the recipient.
out_ciphertext: [u8; 80]A ciphertext enabling the sender to recover the output note.
proof: [u8; 192]A zero-knowledge proof using the Sapling Output circuit.
Implementations
Sourceimpl ShieldedOutput
Auto-generated by derive_getters::Getters.
impl ShieldedOutput
Auto-generated by derive_getters::Getters.
Sourcepub fn ephemeral_key(&self) -> [u8; 32]
pub fn ephemeral_key(&self) -> [u8; 32]
A Jubjub public key.
Sourcepub fn enc_ciphertext(&self) -> [u8; 580]
pub fn enc_ciphertext(&self) -> [u8; 580]
The output note encrypted to the recipient.
Sourcepub fn out_ciphertext(&self) -> [u8; 80]
pub fn out_ciphertext(&self) -> [u8; 80]
A ciphertext enabling the sender to recover the output note.
Sourceimpl ShieldedOutput
impl ShieldedOutput
Sourcepub fn cv(&self) -> ValueCommitment
pub fn cv(&self) -> ValueCommitment
The value commitment to the output note.